==> accounts_management-0.1.6.gem: app/controllers/accounts_management/ledgers/ledger_entries_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgerEntriesController < AccountsManagementController
    # GET /ledgers/ledger_entries
    # GET /ledgers/ledger_entries.json
    def index
      @ledgers_ledger_entries = Ledgers::LedgerEntry.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @ledgers_ledger_entries }
      end
    end

    # GET /ledgers/ledger_entries/1
    # GET /ledgers/ledger_entries/1.json
    def show
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @ledgers_ledger_entry }
      end
    end

    # GET /ledgers/ledger_entries/new
    # GET /ledgers/ledger_entries/new.json
    def new
      @ledgers_ledger_entry = Ledgers::LedgerEntry.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @ledgers_ledger_entry }
      end
    end

    # GET /ledgers/ledger_entries/1/edit
    def edit
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])
    end

    # POST /ledgers/ledger_entries
    # POST /ledgers/ledger_entries.json
    def create
      @ledgers_ledger_entry = Ledgers::LedgerEntry.new(params[:ledgers_ledger_entry])

      respond_to do |format|
        if @ledgers_ledger_entry.save
          format.html { redirect_to @ledgers_ledger_entry, :notice => 'Ledger entry was successfully created.' }
          format.json { render :json => @ledgers_ledger_entry, :status => :created, :location => @ledgers_ledger_entry }
        else
          format.html { render :action => "new" }
          format.json { render :json => @ledgers_ledger_entry.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledger_entries/1
    # PUT /ledgers/ledger_entries/1.json
    def update
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger_entry.update_attributes(params[:ledgers_ledger_entry])
          format.html { redirect_to @ledgers_ledger_entry, :notice => 'Ledger entry was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @ledgers_ledger_entry.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledger_entries/1
    # DELETE /ledgers/ledger_entries/1.json
    def destroy
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])
      @ledgers_ledger_entry.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledger_entries_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/ledgers/ledger_entries_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgerEntriesController < AccountsManagementController
    # GET /ledgers/ledger_entries
    # GET /ledgers/ledger_entries.json
    def index
      @ledgers_ledger_entries = Ledgers::LedgerEntry.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @ledgers_ledger_entries }
      end
    end

    # GET /ledgers/ledger_entries/1
    # GET /ledgers/ledger_entries/1.json
    def show
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @ledgers_ledger_entry }
      end
    end

    # GET /ledgers/ledger_entries/new
    # GET /ledgers/ledger_entries/new.json
    def new
      @ledgers_ledger_entry = Ledgers::LedgerEntry.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @ledgers_ledger_entry }
      end
    end

    # GET /ledgers/ledger_entries/1/edit
    def edit
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])
    end

    # POST /ledgers/ledger_entries
    # POST /ledgers/ledger_entries.json
    def create
      @ledgers_ledger_entry = Ledgers::LedgerEntry.new(params[:ledgers_ledger_entry])

      respond_to do |format|
        if @ledgers_ledger_entry.save
          format.html { redirect_to @ledgers_ledger_entry, notice: 'Ledger entry was successfully created.' }
          format.json { render json: @ledgers_ledger_entry, status: :created, location: @ledgers_ledger_entry }
        else
          format.html { render action: "new" }
          format.json { render json: @ledgers_ledger_entry.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledger_entries/1
    # PUT /ledgers/ledger_entries/1.json
    def update
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger_entry.update_attributes(params[:ledgers_ledger_entry])
          format.html { redirect_to @ledgers_ledger_entry, notice: 'Ledger entry was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @ledgers_ledger_entry.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledger_entries/1
    # DELETE /ledgers/ledger_entries/1.json
    def destroy
      @ledgers_ledger_entry = Ledgers::LedgerEntry.find(params[:id])
      @ledgers_ledger_entry.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledger_entries_url }
        format.json { head :no_content }
      end
    end
  end
end
